herosdevices.hardware.santec.dummy - Heros Devices 0.5.5 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.santec.dummy

Dummy SLM for testing purposes.

## Module Contents

herosdevices.hardware.santec.dummy.log

class herosdevices.hardware.santec.dummy.SantecDummySLM(slots: int = 32)

  Bases: `herosdevices.hardware.santec.template.SantecSLMTemplate`

  Dummy SLM for testing purposes.

  images = [None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None,...
  firmware_serialnumber() → str

    Return a dummy firmware serial number.

  video_mode(mode: int = 0) → str

    Return always ‘OK’. Dummy function.

  push_image(slot: int, image: numpy.typing.NDArray[numpy.uint16]) → str

    Push image data into the dummy slot and return ok.

  contrast_level(value: int) → str

    Return always ‘OK’. Dummy function.

  display_slot(slot: int = 1) → str

    Return always ‘OK’. Dummy function.